@@ -1,6 +1,7 @@
 import logging
 from openhab_pythonrule_engine.item_registry import ItemRegistry
-from openhab_pythonrule_engine.rule_engine import Trigger, CronTrigger, ItemChangedTrigger, RuleLoadedTrigger, RuleEngine
+from openhab_pythonrule_engine.rule_engine import RuleEngine
+from openhab_pythonrule_engine.trigger import CronTrigger, ItemReceivedCommandTrigger, ItemChangedTrigger, RuleLoadedTrigger
 
 
 
@@ -16,7 +17,35 @@ def when(target: str):
             to parse
     """
 
-    if target.lower().startswith("item"):
+    target = target.strip()
+
+
+    if RuleEngine.instance() is None:
+        logging.warning("Environment has not been set. Ignoring decorator '@when(" + target + "')")
+
+        def decorated_method(function):
+            return function
+        return decorated_method
+
+    elif target.lower().startswith("item") and (target.lower().endswith(" received command on") or target.lower().endswith(" received command off")):
+        itemname_operation_pair = target[len("item"):].strip()
+        itemname = itemname_operation_pair[:itemname_operation_pair.index(" ")].strip()
+
+        if ItemRegistry.instance().has_item(itemname):
+            operation = itemname_operation_pair[itemname_operation_pair.index(" "):].strip()
+            operation = operation[len("received "):].strip().lower()
+
+            def decorated_method(function):
+
+                trigger = ItemReceivedCommandTrigger(itemname, operation, target, function)
+                RuleEngine.instance().add_trigger(trigger)
+                return function
+
+            return decorated_method
+        else:
+            logging.warning("item " + itemname + " does not exist (trigger " + target + ")")
+
+    elif target.lower().startswith("item"):
         itemname_operation_pair = target[len("item"):].strip()
         itemname = itemname_operation_pair[:itemname_operation_pair.index(" ")].strip()
 
@@ -51,7 +80,6 @@ def when(target: str):
 
         return decorated_method
 
-
     else:
         logging.warning("unsupported expression " + target + " ignoring it")
         def decorated_method(function):
