@@ -64,7 +64,7 @@ class CronScheduler:
 
     def remove_jobs(self, module: str):
         if module in self.cron_trigger_by_module.keys():
-            logging.info("removing all " + str(len(self.cron_trigger_by_module[module])) + " crons of '" + module + "'")
+            logging.info("removing all " + str(len(self.cron_trigger_by_module[module])) + " cron jobs of '" + module + "'")
             del self.cron_trigger_by_module[module]
 
     def __process(self):
@@ -265,7 +265,6 @@ class RuleEngine:
         triggers: List[ItemTrigger] = self.__trigger_registry.get_triggers_by_type(ItemTrigger)
         item_event = parse_item_event(event)
         if item_event is not None:
-            print(item_event)
             matching_triggers = [trigger for trigger in triggers if trigger.matches(item_event)]
             for item_changed_trigger in matching_triggers:
                 item_changed_trigger.invoke(ItemRegistry.instance())
